@@ -1,3 +1,116 @@
+#  File R/summary.ergmm.R in package latentnet, part of the Statnet suite
+#  of packages for network analysis, http://statnet.org .
+#
+#  This software is distributed under the GPL-3 license.  It is free,
+#  open source, and has the attribution requirements (GPL Section 7) at
+#  http://statnet.org/attribution
+#
+#  Copyright 2003-2017 Statnet Commons
+#######################################################################
+#' ERGMM Fit Summaries
+#' 
+#' \code{summary.ergmm} prodcues a summary of an
+#' \code{\link[=ergmm.object]{ergmm}} object, including point estimates,
+#' standard errors, and BIC calculation.
+#'
+#' @details
+#' Note that BIC computed for the random effects models uses the same
+#' formualtion as Handcock et al., so it is likely correct, but has not been
+#' peer-reviewed.
+#' 
+#' This BIC can be (reasonably) safely used to select the number of clusters or
+#' which fixed effects to include in the model. It is not clear whether it is
+#' appropriate to use this BIC to select the dimension of latent space and
+#' whether or not to include random actor effects. These considerations are
+#' independent of the bug described below.
+#' 
+#' Prior to version 2.7.0, there was a bug in BIC calculation that used \eqn{p
+#' + n(d+r+s)} as the number of parameters in the likelihood (where \eqn{p} is
+#' the number of fixed effects, \eqn{n} the number of actors, \eqn{d}, the
+#' latent space dimension, and \eqn{r} and \eqn{s} indicators of presence of
+#' sender and receiver (or sociality) effects). This value should have been
+#' just \eqn{p}.
+#' 
+#' The following applications could have produced different results:
+#' \itemize{
+#' \item{Using the BIC to select latent space dimension.}
+#' \item{Using the BIC to decide whether or not to include random effects.}
+#' }
+#' The following applications could not (i.e., would be off by a constant):
+#' \itemize{
+#' \item{Using the BIC to select the number of clusters.}
+#' \item{Using the BIC to select the fixed effects to be used.}
+#' }
+#' 
+#' @aliases summary.ergmm print.summary.ergmm summary.ergmm.object bic.ergmm
+#' @param object An \code{\link[=ergmm.object]{ergmm}} object to be summarized.
+#' @param point.est Point estimates to compute: a character vector with some
+#' subset of \code{"mle"}, \code{"pmean"}, \code{"mkl"}, and \code{"pmode"}.
+#' Defaults to a concatenation of \code{"mle"} (if fit), \code{"pmean"}, and
+#' \code{"mkl"} (if MCMC was run).
+#' @param quantiles Posterior quantiles (credible intervals) to compute.
+#' @param se Whether to compute standard errors. Defaults to \code{TRUE} if MLE
+#' was fit.
+#' @param eff.obs,bic.eff.obs What effective sample size to use for BIC
+#' calculation?
+#' \describe{
+#'      \item{\code{"ties"}}{the number of non-missing ties in the network. This is the approach recommended by Handcock et al. (2007) and the default. Not well-defined for valued networks.}
+#'      \item{\code{"dyads"}}{the number of non-missing dyads (potential ties) in the network.}
+#'      \item{\code{"actors"}}{the number of actors in the network. The default prior to 2.7.0.}
+#'      \item{a number}{to specify a specific sample size.}
+#'      \item{\code{NULL}}{Don't compute the BIC at all. Mostly for internal use.}
+#'    }
+#' @param \dots Additional arguments.
+#' @return For \code{summary}, an object of class
+#' \code{\link[=summary.ergmm.object]{summary.ergmm}}. A print method is
+#' available.
+#' 
+#' The BICs are available as the element "bic" of the object returned.
+#' 
+#' \code{bic.ergmm} returns the BIC for the model directly.
+#' @seealso \code{\link{ergmm.object}}, \code{\link{ergmm}}
+#' @references Chris Fraley and Adrian E. Raftery (2002). \emph{Model-based
+#' clustering, discriminant analysis, and density estimation}. Journal of the
+#' American Statistical Association, 97(458), 611-631.
+#' 
+#' Mark S. Handcock, Adrian E. Raftery and Jeremy Tantrum (2007).
+#' \emph{Model-Based Clustering for Social Networks}.  Journal of the Royal
+#' Statistical Society: Series A (Statistics in Society), 170(2), 301-354.
+#' @keywords graphs models print
+#' @examples
+#' 
+#' \donttest{
+#' data(sampson)
+#' # Fit the model for cluster sizes 1 through 4:
+#' fits<-list(
+#'            ergmm(samplike~euclidean(d=2,G=1)),
+#'            ergmm(samplike~euclidean(d=2,G=2)),
+#'            ergmm(samplike~euclidean(d=2,G=3)),
+#'            ergmm(samplike~euclidean(d=2,G=4))
+#'            )
+#' 
+#' \dontrun{
+#' # Optionally, plot all fits.
+#' lapply(fits,plot)
+#' }
+#' 
+#' # Compute the BICs for the fits and plot them:
+#' (bics<-reshape(
+#'     as.data.frame(t(sapply(fits,
+#'                            function(x)c(G=x$model$G,unlist(bic.ergmm(x))[c("Y","Z","overall")])))),
+#'     list(c("Y","Z","overall")),idvar="G",v.names="BIC",timevar="Component",
+#'     times=c("likelihood","clustering","overall"),direction="long"
+#'     ))
+#' 
+#' with(bics,interaction.plot(G,Component,BIC,type="b",xlab="Clusters", ylab="BIC"))
+#' 
+#' # Summarize and plot whichever fit has the lowest overall BIC:
+#' bestG<-with(bics[bics$Component=="overall",],G[which.min(BIC)])
+#' summary(fits[[bestG]])
+#' plot(fits[[bestG]])
+#' }
+#' 
+#' @export
 summary.ergmm <- function (object, point.est=c(
                                      if(!is.null(object[["mle"]])) "mle",
                                      if(!is.null(object[["sample"]])) c("pmean","mkl")),
@@ -37,21 +150,23 @@ summary.ergmm <- function (object, point.est=c(
         if(se){
           beta.hess<-mle[["hessian"]][1:p,1:p]
           
-          beta.cov <- try(robust.inverse(-beta.hess), silent=TRUE)
+          beta.cov <- try(MASS::ginv(-beta.hess), silent=TRUE)
           if(inherits(beta.cov,"try-error")){
             warning("Coefficient Hessian appears to be singular. Using a less accurate estimate.")
             beta.cov <- diag(1/diag(-beta.hess))
           }
+          
+          colnames(beta.cov) <- rownames(beta.cov) <- model[["coef.names"]]
         
-        colnames(beta.cov) <- rownames(beta.cov) <- model[["coef.names"]]
+          mle[["cov"]]<-beta.cov
+          #' @importFrom stats cov2cor
+          mle[["cor"]]<-cov2cor(beta.cov)
         
-        mle[["cov"]]<-beta.cov
-        mle[["cor"]]<-cov2cor(beta.cov)
-        
-        z.values<-mle[["beta"]]/sqrt(diag(mle[["cov"]]))
-        coef.table<-data.frame(mle[["beta"]],sqrt(diag(mle[["cov"]])),
-                               z.values,2*pnorm(abs(z.values),0,1,lower.tail=FALSE),
-                             row.names=model[["coef.names"]])
+          z.values<-mle[["beta"]]/sqrt(diag(mle[["cov"]]))
+          #' @importFrom stats pnorm
+          coef.table<-data.frame(mle[["beta"]],sqrt(diag(mle[["cov"]])),
+                                 z.values,2*pnorm(abs(z.values),0,1,lower.tail=FALSE),
+                                 row.names=model[["coef.names"]])
         }
         else coef.table<-data.frame(mle[["beta"]],
                                     row.names=model[["coef.names"]])
@@ -158,6 +273,7 @@ summary.ergmm <- function (object, point.est=c(
   summ
 }
 
+#' @export
 print.summary.ergmm<-function(x,...){
   ## For convenience
   model<-x[["model"]]
@@ -181,6 +297,7 @@ print.summary.ergmm<-function(x,...){
        
   if(!is.null(x[["pmean"]])){
     cat("Covariate coefficients posterior means:\n")
+    #' @importFrom stats printCoefmat
     printCoefmat(as.matrix(x[["pmean"]][["coef.table"]]),P.values=TRUE,has.Pvalue=TRUE)
     cat("\n")
     if(!is.null(x[["pmean"]][["dispersion"]]))
@@ -236,6 +353,7 @@ print.summary.ergmm<-function(x,...){
   }
 }
 
+#' @export bic.ergmm
 bic.ergmm<-function(object, eff.obs=c("ties", "dyads", "actors"), ...){
   extraneous.argcheck(...)
   if(is.null(object[["mkl"]])){
